netapp_ontap.models.s3_bucket_policy_condition API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.s3_bucket_policy_condition`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class S3BucketPolicyConditionSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the S3BucketPolicyCondition object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `delimiters: List[str] GET POST PATCH`

    An array of delimiters that are compared with the delimiter value specified at the time of execution of an S3-based command, using the condition operator specified.

    Example: ["/"]

  `max_keys: List[Size] GET POST PATCH`

    An array of maximum keys that are allowed or denied to be retrieved using an S3 list operation, based on the condition operator specified.

    Example: [1000]

  `operator: str GET POST PATCH`

    Condition operator that is applied to the specified condition key.

    Valid choices:

    - ip_address
    - not_ip_address
    - string_equals
    - string_not_equals
    - string_equals_ignore_case
    - string_not_equals_ignore_case
    - string_like
    - string_not_like
    - numeric_equals
    - numeric_not_equals
    - numeric_greater_than
    - numeric_greater_than_equals
    - numeric_less_than
    - numeric_less_than_equals
  `prefixes: List[str] GET POST PATCH`

    An array of prefixes that are compared with the input prefix value specified at the time of execution of an S3-based command, using the condition operator specified.

    Example: ["pref"]

  `source_ips: List[str] GET POST PATCH`

    An array of IP address ranges that are compared with the IP address of a source command at the time of execution of an S3-based command, using the condition operator specified.

    Example: ["1.1.1.1","1.2.2.0/24"]

  `usernames: List[str] GET POST PATCH`

    An array of usernames that a current user in the context is evaluated against using the condition operators.

    Example: ["user1"]